<?php
/**
 * Defines all options to be used in the Theme Customiser
 *
 * @package Lambda
 * @subpackage Admin
 *
 * @copyright (c) 2015 Oxygenna.com
 * @license **LICENSE**
 * @version 1.59.12
 * @author Oxygenna.com
 */

// fetch list of skins
$skins = get_posts(array(
    'posts_per_page' => -1,
    'post_type' => 'oxy_stack',
    'orderby' => 'title',
    'order' => 'DESC'
));
$skin_options = array();
foreach ($skins as $skin) {
    $skin_options[$skin->ID] = $skin->post_title;
}

return array(
    array(
        'id'       => 'oxy-site-skin',
        'title'    => esc_html__('Site', 'lambda-admin-td'),
        'priority' => 1,
        'fields'   => array(
            array(
                'id'      => 'site_stack',
                'name'    => esc_html__('Site Skin', 'lambda-admin-td'),
                'desc'    => esc_html__('Sets the current skin used to style the site.', 'lambda-admin-td'),
                'type'    => 'select',
                'default' => '',
                'options' => $skin_options,
            ),
            array(
                'name'    => esc_html__('Layout Type', 'lambda-admin-td'),
                'desc'    => esc_html__('Sets the sites body layout.', 'lambda-admin-td'),
                'id'      => 'layout_type',
                'type'    => 'radio',
                'options' => array(
                    'normal' => esc_html__('Normal', 'lambda-admin-td'),
                    'boxed'  => esc_html__('Boxed', 'lambda-admin-td'),
                ),
                'default' => 'normal',
            )
        )
    ),
    array(
        'id'  => 'oxy-site-logo',
        'title' => esc_html__('Logo', 'lambda-admin-td'),
        'priority' => 2,
        'fields' => array(
            array(
                'name'    => esc_html__('Logo Text', 'lambda-admin-td'),
                'desc'    => esc_html__('Add your logo text here.', 'lambda-admin-td'),
                'id'      => 'logo_text',
                'type'    => 'text',
                'default' => 'Lambda',
            ),
            array(
                'name'    => esc_html__('Logo Image', 'lambda-admin-td'),
                'desc'    => esc_html__('Upload an image to use as the sites logo.', 'lambda-admin-td'),
                'id'      => 'logo_image',
                'store'   => 'url',
                'type'    => 'upload',
                'default' => OXY_THEME_URI . 'assets/images/lamda.png',
            ),
            array(
                'name'    => esc_html__('Logo Transparent Image', 'lambda-admin-td'),
                'desc'    => esc_html__('Upload an image to use as the sites logo when page has a transparent header.', 'lambda-admin-td'),
                'id'      => 'logo_image_trans',
                'store'   => 'url',
                'type'    => 'upload',
                'default' => '',
            ),
        )
    ),
    array(
        'id'  => 'oxy-header',
        'title' => esc_html__('Header', 'lambda-admin-td'),
        'priority' => 3,
        'fields' => array(
            array(
                'name'    => esc_html__('Style', 'lambda-admin-td'),
                'desc'    => esc_html__('Choose a layout for your headers menu & logo', 'lambda-admin-td'),
                'id'      => 'header_style',
                'type'    => 'select',
                'options' => array(
                    'logo-left-menu-right'     => esc_html__('Logo Left - Menu Right', 'lambda-admin-td'),
                    'logo-right-menu-left'     => esc_html__('Logo Right - Menu Left', 'lambda-admin-td'),
                    'logo-right-menu-below'    => esc_html__('Logo Right - Menu Below', 'lambda-admin-td'),
                    'logo-left-menu-below'     => esc_html__('Logo Left - Menu Below', 'lambda-admin-td'),
                    'logo-center-menu-below'   => esc_html__('Logo Center - Menu Below', 'lambda-admin-td'),
                    'logo-left-menu-sidebar'   => esc_html__('Logo Left - Menu Sidebar', 'lambda-admin-td'),
                    'fixed-left-menu-sidebar'  => esc_html__('Fixed Left - Menu Sidebar', 'lambda-admin-td'),
                    'fixed-right-menu-sidebar' => esc_html__('Fixed Right - Menu Sidebar', 'lambda-admin-td')
                ),
                'default' => 'logo-left-menu-right',
            ),
            array(
                'name'    => esc_html__('Menu Align', 'lambda-admin-td'),
                'desc'    => esc_html__('Set the alignment of the dropdown menu.', 'lambda-admin-td'),
                'id'      => 'header_menu_align',
                'type'    => 'radio',
                'options' => array(
                    'dropdown-menu-left'  => esc_html__('Left', 'lambda-admin-td'),
                    'dropdown-menu-right' => esc_html__('Right', 'lambda-admin-td'),
                ),
                'default' => 'dropdown-menu-left',
            ),
            array(
                'name'    => esc_html__('Width', 'lambda-admin-td'),
                'desc'    => esc_html__('Set the width of the header container.', 'lambda-admin-td'),
                'id'      => 'header_container',
                'type'    => 'radio',
                'options' => array(
                    'container'           => esc_html__('Normal', 'lambda-admin-td'),
                    'container-fullwidth' => esc_html__('Full Width', 'lambda-admin-td'),
                ),
                'default' => 'container',
            ),
            array(
                'name'    => esc_html__('Sticky', 'lambda-admin-td'),
                'desc'    => esc_html__('Make the navigation stick to the top of the page.', 'lambda-admin-td'),
                'id'      => 'header_sticky',
                'type'    => 'radio',
                'options' => array(
                    'navbar-sticky'     => esc_html__('On', 'lambda-admin-td'),
                    'navbar-not-sticky' => esc_html__('Off', 'lambda-admin-td'),
                ),
                'default' => 'navbar-sticky',
            ),
            array(
                'name'    => esc_html__('Sticky on Mobile', 'lambda-admin-td'),
                'desc'    => esc_html__('Enable sticky navigation for mobile devices(works only if the menu is sticky for large screens as well).', 'lambda-admin-td'),
                'id'      => 'header_sticky_mobile',
                'type'    => 'radio',
                'options' => array(
                    'navbar-mobile-stuck'     => esc_html__('On', 'lambda-admin-td'),
                    'navbar-not-mobile-stuck' => esc_html__('Off', 'lambda-admin-td'),
                ),
                'default' => 'navbar-not-mobile-stuck',
            ),
            array(
                'name'    => esc_html__('Top Bar', 'lambda-admin-td'),
                'desc'    => esc_html__('Adds a top bar to the top of your page above the main header.', 'lambda-admin-td'),
                'id'      => 'header_top_bar',
                'type'    => 'radio',
                'options' => array(
                    'on'  => esc_html__('On', 'lambda-admin-td'),
                    'off' => esc_html__('Off', 'lambda-admin-td'),
                ),
                'default' => 'off',
            ),
            array(
                'name'    => esc_html__(' Text Capitalization', 'lambda-admin-td'),
                'desc' => esc_html__('Sets the case of the text inside your header.', 'lambda-admin-td'),
                'id'      => 'header_capitalization',
                'type'    => 'radio',
                'options' => array(
                    'text-caps'      => esc_html__('Force Uppercase', 'lambda-admin-td'),
                    'text-lowercase' => esc_html__('Force Lowercase', 'lambda-admin-td'),
                    'text-none' => esc_html__('Off', 'lambda-admin-td'),
                ),
                'default' => 'text-none',
            ),
            array(
                'name'      => esc_html__('Navbar Scroll Change Point', 'lambda-admin-td'),
                'desc' => esc_html__('Point in pixels after the page scrolls that will trigger the menu to change height.', 'lambda-admin-td'),
                'id'        => 'navbar_scrolled_point',
                'type'      => 'slider',
                'default'   => 30,
                'attr'      => array(
                    'max'       => 1000,
                    'min'       => 0,
                    'step'      => 1
                )
            ),
            array(
                'name'    => esc_html__('Hover Menu', 'lambda-admin-td'),
                'desc' => esc_html__('Choose between menu that will open when you click or hover (desktop only option since mobile devices will always use touch)', 'lambda-admin-td'),
                'id'      => 'hover_menu',
                'type'    => 'radio',
                'options' => array(
                    'off' => esc_html__('Click', 'lambda-admin-td'),
                    'on'  => esc_html__('Hover', 'lambda-admin-td'),
                ),
                'default' => 'off',
            ),
            array(
                'name'    => esc_html__('Hover Menu Delay', 'lambda-admin-td'),
                'desc'    => esc_html__('Delay in seconds before the hover menu closes after moving mouse off the menu.', 'lambda-admin-td'),
                'id'      => 'hover_menu_delay',
                'type'      => 'slider',
                'default'   => 200,
                'attr'      => array(
                    'max'       => 1000,
                    'min'       => 0,
                    'step'      => 1
                )
            ),
            array(
                'name'    => esc_html__('Hover Menu Fade Delay', 'lambda-admin-td'),
                'desc'    => esc_html__('Delay of the Fade In/Fade Out animation .', 'lambda-admin-td'),
                'id'      => 'hover_menu_fade_delay',
                'type'      => 'slider',
                'default'   => 200,
                'attr'      => array(
                    'max'       => 1000,
                    'min'       => 0,
                    'step'      => 1
                )
            ),
            array(
                'name'    => esc_html__('Side Menu Close On Click', 'lambda-admin-td'),
                'desc'    => esc_html__('If Menu Sidebar is set(not for fixed sidebar), close on click.', 'lambda-admin-td'),
                'id'      => 'menu_close',
                'type'    => 'radio',
                'options' => array(
                    'on'  => esc_html__('On', 'lambda-admin-td'),
                    'off' => esc_html__('Off', 'lambda-admin-td'),
                ),
                'default' => 'off'
            )
        )
    ),
    array(
        'id'       => 'upper-footer-section',
        'title'    => esc_html__('Upper Footer', 'lambda-admin-td'),
        'priority' => 4,
        'fields'   => array(
            array(
                'name'    => esc_html__('Upper Footer Columns', 'lambda-admin-td'),
                'desc'    => esc_html__('Select how many columns the upper footer will consist of.', 'lambda-admin-td'),
                'id'      => 'upper_footer_columns',
                'type'    => 'select',
                'options' => array(
                    0  => esc_html__('0', 'lambda-admin-td'),
                    1  => esc_html__('1', 'lambda-admin-td'),
                    2  => esc_html__('2', 'lambda-admin-td'),
                    3  => esc_html__('3', 'lambda-admin-td'),
                    4  => esc_html__('4', 'lambda-admin-td'),
                ),
                'default' => 0,
            ),
            array(
                'name'    => esc_html__('Upper Footer Top Padding', 'lambda-admin-td'),
                'desc'    => esc_html__('Sets the amount of padding to add to the top of the upper footer.', 'lambda-admin-td'),
                'id'      => 'upper_footer_padding_top',
                'type'    => 'slider',
                'default' => 20,
                'attr'    => array(
                    'max'       => 300,
                    'min'       => 0,
                    'step'      => 10,
                )
            ),
            array(
                'name'    => esc_html__('Upper Footer Bottom Padding', 'lambda-admin-td'),
                'desc'    => esc_html__('Sets the amount of padding to add to the bottom of the upper footer.', 'lambda-admin-td'),
                'id'      => 'upper_footer_padding_bottom',
                'type' => 'slider',
                'default'   => 20,
                'attr'      => array(
                    'max'       => 300,
                    'min'       => 0,
                    'step'      => 10,
                )
            )
        )
    ),
    array(
        'id'     => 'footer-section',
        'title'  => esc_html__('Footer', 'lambda-admin-td'),
        'priority' => 5,
        'fields' => array(
            array(
                'name'    => esc_html__('Footer Columns', 'lambda-admin-td'),
                'desc'    => esc_html__('Select how many columns the footer will consist of.', 'lambda-admin-td'),
                'id'      => 'footer_columns',
                'type'    => 'select',
                'options' => array(
                    0  => esc_html__('0', 'lambda-admin-td'),
                    1  => esc_html__('1', 'lambda-admin-td'),
                    2  => esc_html__('2', 'lambda-admin-td'),
                    3  => esc_html__('3', 'lambda-admin-td'),
                    4  => esc_html__('4', 'lambda-admin-td'),
                ),
                'default' => 4,
            ),
            array(
                'name'    => esc_html__('Footer Top Padding', 'lambda-admin-td'),
                'desc'    => esc_html__('Sets the amount of padding to add to the top of the footer.', 'lambda-admin-td'),
                'id'      => 'footer_padding_top',
                'type' => 'slider',
                'default'   => 40,
                'attr'      => array(
                    'max'       => 300,
                    'min'       => 0,
                    'step'      => 10,
                )
            ),
            array(
                'name'    => esc_html__('Footer Bottom Padding', 'lambda-admin-td'),
                'desc'    => esc_html__('Sets the amount of padding to add to the bottom of the footer.', 'lambda-admin-td'),
                'id'      => 'footer_padding_bottom',
                'type' => 'slider',
                'default'   => 40,
                'attr'      => array(
                    'max'       => 300,
                    'min'       => 0,
                    'step'      => 10,
                )
            ),
            array(
                'name'    => esc_html__('Back to top button', 'lambda-admin-td'),
                'desc'    => esc_html__('Show or hide the back to top button that appears when you scroll down the page.', 'lambda-admin-td'),
                'id'      => 'back_to_top',
                'type'    => 'radio',
                'options' => array(
                    'enable'  => esc_html__('Enable', 'lambda-admin-td'),
                    'disable'  => esc_html__('Disable', 'lambda-admin-td'),
                ),
                'default' => 'enable',
            ),
            array(
                'name'    => esc_html__('Back to top button - Mobiles', 'lambda-admin-td'),
                'desc'    => esc_html__('Show(previous option needs to be enabled) or hide the back to top button on mobile devices.', 'lambda-admin-td'),
                'id'      => 'back_to_top_mobile',
                'type'    => 'radio',
                'options' => array(
                    'enable'  => esc_html__('Enable', 'lambda-admin-td'),
                    'disable'  => esc_html__('Disable', 'lambda-admin-td'),
                ),
                'default' => 'disable',
            ),
            array(
                'name'    => esc_html__('Back to top shape', 'lambda-admin-td'),
                'desc'    => esc_html__('Set the shape of the back to top button.', 'lambda-admin-td'),
                'id'      => 'back_to_top_shape',
                'type'    => 'radio',
                'options' => array(
                    'square' => esc_html__('Square', 'lambda-admin-td'),
                    'circle'  => esc_html__('Circle', 'lambda-admin-td'),
                ),
                'default' => 'square'
            )
        )
    ),
    array(
        'id'     => 'sub-footer-section',
        'title'  => esc_html__('Sub Footer', 'lambda-admin-td'),
        'priority' => 5,
        'fields' => array(
            array(
                'name'    => esc_html__('Sub Footer Columns', 'lambda-admin-td'),
                'desc'    => esc_html__('Select how many columns the footer will consist of.', 'lambda-admin-td'),
                'id'      => 'sub_footer_columns',
                'type'    => 'select',
                'options' => array(
                    0  => esc_html__('0', 'lambda-admin-td'),
                    1  => esc_html__('1', 'lambda-admin-td'),
                    2  => esc_html__('2', 'lambda-admin-td'),
                    3  => esc_html__('3', 'lambda-admin-td'),
                    4  => esc_html__('4', 'lambda-admin-td'),
                ),
                'default' => 2,
            )
        )
    )
);
